# PDKMaster integration with KLayout

This is PDKMaster module to provide interoperation with SPICE simulators.
This is WIP version with just the red tape setup for the project.

# Release history

* [v0.1.0](https://gitlab.com/Chips4Makers/pdkmaster-io-spice/-/commits/v0.1.0):
  First version of split off module. Next to the copied code from PDKMaster it contains some clean-up and update for other API changes done for PDKMaster 0.12.0.

## Project Arrakeen subproject

This project is part of Chips4Makers' [project Arrakeen](https://gitlab.com/Chips4Makers/c4m-arrakeen). It shares some common guide lines and regulations:

* [Contributing.md](https://gitlab.com/Chips4Makers/c4m-arrakeen/-/blob/redtape_v1/Contributing.md)
* [LICENSE.md](https://gitlab.com/Chips4Makers/c4m-arrakeen/-/blob/redtape_v1/LICENSE.md): license of release code
* [LICENSE_rationale.md](https://gitlab.com/Chips4Makers/c4m-arrakeen/-/blob/redtape_v1/LICENSE_rationale.md)
